Error

Enum Error 

pub enum Error {
Show 20 variants InvalidArgument, OutOfSpace, ParseFailure, ResponseTimeout, BadResponse, UnknownMessageCode, UnhandledCriticalOption, IOError, Cancelled, HostNotFound, HostLookupFailure, ResourceNotFound, Unauthorized, Forbidden, ClientRequestError, ServerError, Reset, OptionNotRepeatable, UnsupportedUriScheme, Unspecified,
}
Type for errors encountered while sending or receiving CoAP requests and responses.

Variants



InvalidArgument

One or more of the supplied arguments are not valid for the given operation.



OutOfSpace

There is not enough space in the given buffer to complete the operation.



ParseFailure

An error was encountered while attempting to parse the data.



ResponseTimeout

Operation timed out waiting for a response.



BadResponse

The response was well-formed, but not appropriate for the given request.



UnknownMessageCode

The [message code][async-coap::message::MsgCode] was not recognized by this version of rust-async-coap.



UnhandledCriticalOption

A critical option present in the message was not supported.



IOError

An I/O error occurred while performing this operation.



Cancelled

This operation has been cancelled.



HostNotFound

Unable to look up the given host because it was not found.



HostLookupFailure

Unable to look up the given host for an unspecified reason.



ResourceNotFound

The response indicated that the given resource was not found.



Unauthorized

The response indicated that the request was unauthorized.



Forbidden

The response indicated that the request was forbidden.



ClientRequestError

The response indicated an unspecified client error.



ServerError

The response indicated an unspecified server error.



Reset

The transaction was reset.



OptionNotRepeatable

More than one instance of an option marked as non-repeatable was encountered.



UnsupportedUriScheme

The given URI scheme is not supported by the associated local endpoint.



Unspecified

An unspecified error has occurred.