MsgType

Enum MsgType 

pub enum MsgType {
    Con = 0,
    Non = 1,
    Ack = 2,
    Res = 3,
}
Enum representing the CoAP message type: CON, NON, ACK, and RES.

Variants



Con = 0

Variant for confirmable CoAP messages.



Non = 1

Variant for non-confirmable CoAP messages.



Ack = 2

Variant for CoAP message acknowledgements.



Res = 3

Variant for CoAP reset messages.

Implementations

Source

impl MsgType

pub fn from(tt: u8) -> MsgType

Creates a new MsgType from the given value, panicing if the value is invalid.

pub fn try_from(tt: u8) -> Option<MsgType>

Creates a new MsgType from the given value, returning None if the value is invalid.

pub fn is_non(self) -> bool

Returns true if this message type is nonconfirmable (NON).

pub fn is_con(self) -> bool

Returns true if this message type is confirmable (CON).

pub fn is_ack(self) -> bool

Returns true if this message type is an acknowledgement (ACK).

pub fn is_res(self) -> bool

Returns true if this message type is a reset (RES).